@@ -23,6 +23,7 @@
 #include "configdlg.h"
 
 #include <QCheckBox>
+#include <QCompleter>
 #include <QDir>
 #include <QFileDialog>
 #include <QMessageBox>
@@ -79,9 +80,9 @@ ConfigDlg::ConfigDlg(GlobalGUIConfig* c, TraceData* data,
     objectCombo->setDuplicatesEnabled(false);
     classCombo->setDuplicatesEnabled(false);
     fileCombo->setDuplicatesEnabled(false);
-    objectCombo->setAutoCompletion(true);
-    classCombo->setAutoCompletion(true);
-    fileCombo->setAutoCompletion(true);
+    objectCombo->setCompleter(new QCompleter(objectCombo));
+    classCombo->setCompleter(new QCompleter(classCombo));
+    fileCombo->setCompleter(new QCompleter(fileCombo));
 
     // first unspecified cost items from data
     TraceObjectMap::Iterator oit;
@@ -114,15 +115,15 @@ ConfigDlg::ConfigDlg(GlobalGUIConfig* c, TraceData* data,
 
         QString n = cs->_name;
         if (n.startsWith(objectPrefix)) {
-            n = n.remove(0, objectPrefix.length()+1);
+            n.remove(0, objectPrefix.length()+1);
             if (oList.indexOf(n) == -1) oList.append(n);
         }
         else if (n.startsWith(classPrefix)) {
-            n = n.remove(0, classPrefix.length()+1);
+            n.remove(0, classPrefix.length()+1);
             if (cList.indexOf(n) == -1) cList.append(n);
         }
         else if (n.startsWith(filePrefix)) {
-            n = n.remove(0, filePrefix.length()+1);
+            n.remove(0, filePrefix.length()+1);
             if (fList.indexOf(n) == -1) fList.append(n);
         }
     }
